@@ -68,10 +68,16 @@ class GS_assignment_Grader:
             return self.sub_to_questions_mapping
     
     def email_to_qids(self, email_to_sub: dict=None, sub_to_q: dict = None, verbose: bool=False, force: bool=False) -> dict:
-        if not email_to_sub:
+        while not email_to_sub:
             email_to_sub = self.student_email_to_submission_ids(verbose=verbose, force=force)
-        if not sub_to_q:
+            if email_to_sub:
+                break
+            print("Failed to get student email to submission ids! Trying again...")
+        while not sub_to_q:
             sub_to_q = self.sub_id_to_questions_id(verbose=verbose, force=force)
+            if sub_to_q:
+                break
+            print("Failed to get submission ids to question ids mapping! Trying again...")
         emails_to_qids_dict = {}
         for email, sub_id in email_to_sub.items():
             if sub_id in sub_to_q:
@@ -110,10 +116,15 @@ class GS_assignment_Grader:
                 )
             
 
-    def update_outline(self, outline: "GS_Outline") -> "GS_Outline":
-
-        if self.client.edit_outline(self.course_id, self.assignment_id, outline.json()):
-            return self.get_outline()
+    def update_outline(self, outline: "GS_Outline", return_outline: bool=True) -> "GS_Outline":
+        res = self.client.edit_outline(self.course_id, self.assignment_id, outline.json())
+        if res:
+            if return_outline:
+                return self.get_outline()
+            else:
+                return True
+        return res
+        
     
     def get_questions(self, raw_outline_data: str=None) -> ["GS_Question"]:
         if not raw_outline_data:
@@ -272,6 +283,9 @@ class GS_Question:
         self.weight = weight
         self.index = index
         self.data = None # Extra variable for other programs to use
+
+    def __repr__(self):
+        return f"GS_Question({self.assignment_grader}, {self.question_id}, {self.parent}, {self.children}, {self.q_type}, {self.title}, {self.weight}, {self.index}, {self.data})"
     
     def set_children(self, children: ["GS_Question"]):
         self.children = children
@@ -384,6 +398,9 @@ class RubricItem:
             }
         }
 
+    def __repr__(self):
+        return f"RubricItem({self.item_id}, {self.description}, {self.weight}, {self.group_id}, {self.position})"
+
 
 class QuestionRubric:
     def __init__(self, question: GS_Question):
@@ -395,6 +412,9 @@ class QuestionRubric:
             for item in raw_rubric_items.get("rubric_items", []):
                 self.rubric_items.append(RubricItem(**item))
 
+    def __repr__(self):
+        return f"QuestionRubric({self.question}, {self.rubric_items})"
+
     def add_rubric_item(self, rubric_item: RubricItem) -> bool:
         self.rubric_items.append(rubric_item)
         rubric_item.item_id = self.question.add_rubric_item(rubric_item.description, rubric_item.weight)
