@@ -104,6 +104,9 @@ class GS_autograder:
             print_fn(stderr)
         return self.is_built(recheck=False)
 
+    def set_manual_configuration(self, image: str) -> bool:
+        return self.client.set_manual_ag_config(self.class_id, self.assignment_id, image)
+
     def regrade_all(self) -> bool:
         return self.client.regrade_all(self.class_id, self.assignment_id)
 
