@@ -3,7 +3,7 @@ import click
 from fullGSapi.api.gs_api_client import GradescopeAPIClient
 from fullGSapi.api.client import GradescopeClient
 
-from fullGSapi.cli.utils import login_token_path_option, LoginTokens
+from fullGSapi.cli.utils import login_token_path_option, LoginTokens, get_clients
 
 @click.command()
 @click.option('--email', '-e', 'email', prompt=True, type=str)
@@ -26,4 +26,11 @@ def login(ctx, email: str, password: str, tokenpath: str):
             click.echo("Failed to login to the frontend API!")
     else:
         click.echo("Failed to login to the official API!")
-    return False
\ No newline at end of file
+    return False
+
+@click.command()
+@click.pass_context
+def check_login(ctx):
+    status = get_clients(ctx, ctx.obj["TOKENPATH"])
+    if not status:
+        click.echo("You are not logged in!")
\ No newline at end of file
